@@ -45,8 +45,19 @@ class WaringCategory(models.Model):
 
 class Warning(SimpleTask):
 
+    FAILED = 50
+
+    STATUS = [
+        (SimpleTask.READY, _("Message Not sent yet")),
+        (SimpleTask.DOING, _("Message is sending")),
+        (SimpleTask.DONE, _("Messgage Sent")),
+    ]
+    
     send_notify_callbacks = []
 
+    status = models.IntegerField(choices=STATUS, default=SimpleTask.READY, verbose_name=_("Notify Status"), editable=False)
+    success = models.BooleanField(null=True, verbose_name=_("Notify Sent Success"), editable=False)
+
     category = models.ForeignKey(WaringCategory, on_delete=models.SET_NULL, null=True, blank=True, verbose_name=_("Warning Category"))
     title = SafeCharField(max_length=1024, verbose_name=_("Warning Title"))
     data = SafeTextField(null=True, blank=True, verbose_name=_("Warning Data"))
