@@ -18,21 +18,18 @@ def sendmail_notify(warning, payload, force):
     subject = warning.get_notify_email_subject()
     content = warning.get_notify_email_content()
 
-    try:
-        sendmail(
-            from_address,
-            to_addresses,
-            content,
-            subject,
-            attachs=None,
-            is_html_content=True,
-            encoding="utf-8",
-            charset="utf-8",
-            host=server,
-            port=port,
-            ssl=ssl,
-            user=user,
-            password=password,
-            )
-    except Exception as error:
-        logger.exception(f"send notify email failed: {error}")
+    sendmail(
+        from_address,
+        to_addresses,
+        content,
+        subject,
+        attachs=None,
+        is_html_content=True,
+        encoding="utf-8",
+        charset="utf-8",
+        host=server,
+        port=port,
+        ssl=ssl,
+        user=user,
+        password=password,
+        )
